@@ -1,15 +1,13 @@
-/*
- *   bin86/as/keywords.c
- *
- *   Copyright (C) 1992 Bruce Evans
- */
-
-/* keywords.c - keywords for assembler */
+/* keywords.c - keyword tables for assembler */
 
+#include "syshead.h"
 #include "const.h"
 #include "type.h"
+#include "globvar.h"
 #include "opcode.h"
 
+/* --- start of keywords --- */
+
 /* registers */
 /* the register code (internal to assembler) is given in 1 byte */
 /* the "opcode" field is not used */
@@ -97,6 +95,7 @@ PUBLIC char typesizes[] =
     5, 'D', 'W', 'O', 'R', 'D', DWORDOP, 4,
     5, 'F', 'W', 'O', 'R', 'D', FWORDOP, 6,
     3, 'F', 'A', 'R', FAROP, 0,
+    4, 'N', 'E', 'A', 'R', WORDOP, 2,
     3, 'P', 'T', 'R', PTROP, 0,
     5, 'P', 'W', 'O', 'R', 'D', PWORDOP, 6,
     5, 'Q', 'W', 'O', 'R', 'D', QWORDOP, 8,
@@ -125,6 +124,7 @@ PUBLIC char ops[] =
     /* unconditionals */
     6, '.', 'A', 'L', 'I', 'G', 'N', ALIGNOP, 0,
     6, '.', 'A', 'S', 'C', 'I', 'I', FCCOP, 0,
+    6, '.', 'A', 'S', 'C', 'I', 'Z', ASCIZOP, 0,
     5, '.', 'B', 'L', 'K', 'B', RMBOP, 0,
     5, '.', 'B', 'L', 'K', 'W', BLKWOP, 0,
     5, 'B', 'L', 'O', 'C', 'K', BLOCKOP, 0,
@@ -135,14 +135,18 @@ PUBLIC char ops[] =
     5, '.', 'D', 'A', 'T', 'A', DATAOP, 0,
     6, '.', 'D', 'A', 'T', 'A', '1', FCBOP, 0,
     6, '.', 'D', 'A', 'T', 'A', '2', FDBOP, 0,
+#if SIZEOF_OFFSET_T > 2
     6, '.', 'D', 'A', 'T', 'A', '4', FQBOP, 0,
+#endif
     2, 'D', 'B', FCBOP, 0,
+#if SIZEOF_OFFSET_T > 2
     2, 'D', 'D', FQBOP, 0,
+#endif
     7, '.', 'D', 'E', 'F', 'I', 'N', 'E', EXPORTOP, 0,
     2, 'D', 'W', FDBOP, 0,
     3, 'E', 'N', 'D', PROCEOFOP, 0,
     4, 'E', 'N', 'D', 'B', ENDBOP, 0,
-    5, 'E', 'N', 'T', 'E', 'R', ENTEROP, 0,
+    6, '.', 'E', 'N', 'T', 'E', 'R', ENTEROP, 0,
     5, 'E', 'N', 'T', 'R', 'Y', ENTRYOP, 0,
     3, 'E', 'Q', 'U', EQUOP, 0,
     5, '.', 'E', 'V', 'E', 'N', EVENOP, 0,
@@ -156,6 +160,7 @@ PUBLIC char ops[] =
     3, 'F', 'C', 'C', FCCOP, 0,
     3, 'F', 'D', 'B', FDBOP, 0,
     3, 'G', 'E', 'T', GETOP, 0,
+    7, '.', 'G', 'L', 'O', 'B', 'A', 'L', GLOBLOP, 0,
     6, '.', 'G', 'L', 'O', 'B', 'L', GLOBLOP, 0,
     5, 'I', 'D', 'E', 'N', 'T', IDENTOP, 0,
     6, 'I', 'M', 'P', 'O', 'R', 'T', IMPORTOP, 0,
@@ -164,7 +169,9 @@ PUBLIC char ops[] =
     6, '.', 'L', 'C', 'O', 'M', 'M', LCOMMOP1, 0,
     5, '.', 'L', 'I', 'S', 'T', LISTOP, 0,
     3, 'L', 'O', 'C', LOCOP, 0,
+#if SIZEOF_OFFSET_T > 2
     5, '.', 'L', 'O', 'N', 'G', FQBOP, 0,
+#endif
     8, '.', 'M', 'A', 'C', 'L', 'I', 'S', 'T', MACLISTOP, 0,
     5, 'M', 'A', 'C', 'R', 'O', MACROOP, 0,
     4, '.', 'M', 'A', 'P', MAPOP, 0,
@@ -179,8 +186,10 @@ PUBLIC char ops[] =
     6, '.', 'S', 'H', 'O', 'R', 'T', FDBOP, 0,
     6, '.', 'S', 'P', 'A', 'C', 'E', RMBOP, 0,
     5, '.', 'T', 'E', 'X', 'T', TEXTOP, 0,
+#ifndef MC6809
     5, 'U', 'S', 'E', '1', '6', USE16OP, 0,
     5, 'U', 'S', 'E', '3', '2', USE32OP, 0,
+#endif
     5, '.', 'W', 'A', 'R', 'N', WARNOP, 0,
     5, '.', 'W', 'O', 'R', 'D', FDBOP, 0,
     6, '.', 'Z', 'E', 'R', 'O', 'W', BLKWOP, 0,
@@ -702,7 +711,7 @@ PUBLIC char bytesizeops[] =
     4, 'A', 'D', 'D', 'B', GROUP1, 0x00,
     4, 'A', 'N', 'D', 'B', GROUP1, 0x20,
     4, 'C', 'M', 'P', 'B', GROUP1, CMP_OPCODE_BASE,
-    4, 'D', 'E', 'C', 'b', INCDEC, 0x08,
+    4, 'D', 'E', 'C', 'B', INCDEC, 0x08,
     4, 'D', 'I', 'V', 'B', DIVMUL, 0x30,
     5, 'I', 'D', 'I', 'V', 'B', DIVMUL, 0x38,
     5, 'I', 'M', 'U', 'L', 'B', IMUL, 0x28,
@@ -731,3 +740,5 @@ PUBLIC char bytesizeops[] =
 };
 # endif /* MNSIZE */
 #endif /* I80386 */
+
+/* --- end of keywords --- */
